package elements;

import elements.exceptions.NoChatNameException;
import elements.exceptions.NoUsernameException;
import org.json.JSONObject;

/**
 * Created by Guillermo Serrahima on 10/8/16.
 */
public class ChannelMessage extends Message {
    private Long cid;         //chat id
    private Integer mid;      //message id
    private Integer uid;      //user id
    private String chatType;  //chat type
    private String fullName;  //author name
    private String userName;  //username
    private String chatName;  //chat name
    private String text;      //the actual message
    private String consoleLog;

    public ChannelMessage(JSONObject message) {
        super(message);
        cid = message.getJSONObject("chat").getLong("id");
        mid = message.getInt("message_id");
        chatType = message.getJSONObject("chat").getString("type");

        //Check for User
        if(message.has("from")) {
            fullName = message.getJSONObject("from").getString("first_name");
            uid = message.getJSONObject("from").getInt("id");

            //Check for user last name
            if (message.getJSONObject("from").has("last_name"))
                fullName += " " + message.getJSONObject("from").getString("last_name");

            //Check for user username
            if (message.getJSONObject("from").has("username"))
                userName = message.getJSONObject("from").getString("username");
            else userName = null;
        }

        else {
            fullName = null;
            uid = null;
            userName = null;
        }

        //Get group chat name
        if (message.getJSONObject("chat").has("title"))
            chatName = message.getJSONObject("chat").getString("title");
        else chatName = null;

        if (message.has("text"))
            text = message.getString("text");
        else text = null;

        consoleLog = message.toString();
    }

    public long getCid() {
        return cid;
    }

    public long getMid() {
        return mid;
    }

    public int getUid() {
        return uid;
    }

    public String getAuthor() {
        return fullName;
    }

    public boolean hasUsername() {
        return userName != null;
    }

    public String getUsername() throws NoUsernameException {
        if(userName == null) throw new NoUsernameException();
        return userName;
    }

    public String getChatName() throws NoChatNameException {
        if(userName == null) throw new NoChatNameException();
        return chatName;
    }

    public boolean hasText() {
        return text != null;
    }

    public String getText() {
        return text;
    }

    public boolean isGroup() {
        return chatType.contains("group");
    }

    public boolean isBasicGroup() {
        return chatType.equals("group");
    }

    public boolean isSupergroup() {
        return chatType.equals("supergroup");
    }

    public boolean isChannel() {
        return chatType.equals("channel");
    }

    public boolean isPrivate() {
        return chatType.equals("private");
    }

    @Override
    public String toString() {
        return consoleLog;
    }
}
